<?php  
/* 
Plugin Name: Dimme Googlemap
Plugin URI: http://dev.dimme.nl
Description: Googlemap plugin using custom post types.
Version: 1.0 
Author: Dimme
Author URI: http://Dimme.nl 
*/  

function dimme_googlemaps_show_term_table() {
	$terms = dimme_googlemaps_get_term_table();
	$link = get_permalink(get_the_ID());
	
	foreach($terms as $k => $term) {
		$terms["$k"]->link = $link . sprintf("?tax=%s&term=%s", $term->taxonomy, $term->slug);
	}
	echo '<div class="tag-cloud">';
	echo wp_generate_tag_cloud($terms);
	echo '</div>';
}
function dimme_googlemaps_get_term_table() {
	$postType = get_option('dimme_googlemaps_posttype');
	$postType = $postType ? $postType : "googlemap";
	$taxonomies = get_object_taxonomies($postType);
	$terms = get_terms($taxonomies, array("orderby" => "count", "order" => "DESC"));
	return $terms;
}			

function get_dimme_googlemaps($month = false, $year = false, $tax = false, $term = false) {
	$postType = get_option('dimme_googlemaps_posttype');
	$postType = $postType ? $postType : "googlemap";
	
	$loopArray = array( 'post_type' => $postType, 'posts_per_page' => -1, 'post_status' => 'publish,future', 'taxonomy' => 'demo', 'term' => 'test2');
	if($tax && $term) {
		$loopArray["taxonomy"] = $tax;
		$loopArray["term"] = $term;
	}
	$loop = new WP_Query( $loopArray );
	
	$dates = Array();
	while ( $loop->have_posts() ) : $loop->the_post();
		$d = strtotime($loop->post->post_date);
		$post = $loop->post;
		$post->permalink = get_permalink();
		$post->latitude = get_post_meta( $post->ID, 'latitude', true);
		$post->longtitude = get_post_meta( $post->ID, 'longtitude', true);
		$googlemap[] = $post;
	endwhile;
	
	$output["googlemap"] = $googlemap;
	return $output;
}

function dimme_googlemaps_admin_init() {
	//echo get_option('my_first_data');
}
function dimme_googlemaps_admin() {  
	include('dimme-googlemaps-admin.php');
}  
function dimme_googlemaps_admin_actions() {  
  add_options_page("Dimme Googlemap", "Dimme Googlemap", 'administrator', "dimme_googlemaps_admin_init", "dimme_googlemaps_admin");  
}  
function dimme_googlemaps_add_custom_box() {
	$postType = get_option('dimme_googlemaps_posttype');
	add_meta_box( 'id', __( 'Googlemaps', 'dimme-googlemaps' ), 'dimme_googlemaps_inner_custom_box', $postType , 'normal', 'core');
}
function dimme_googlemaps_inner_custom_box() {
	// Use nonce for verification
	
  wp_nonce_field( plugin_basename(__FILE__), 'dimme-googlemaps' );
  global $post_id;
  
  $latitude = get_post_meta( $post_id, 'latitude', true);
  $longtitude = get_post_meta( $post_id, 'longtitude', true);
  
  // The actual fields for data entry
  echo '<label for="latitude">' . __("Latitude", 'dimme-googlemaps' ) . '</label> ';
  echo '<input type="text" id="latitude" name="latitude" value="' . $latitude . '" size="25" /> <br>';
  echo '<label for="longtitude">' . __("Longtitude", 'dimme-googlemaps' ) . '</label> ';
  echo '<input type="text" id="longtitude" name="longtitude" value="' . $longtitude . '" size="25" /> <br>';
  echo '<div id="dimme-googlemaps-map" style="width:100%;height:400px;">a</div>';
}
function dimme_googlemaps_save_postdata( $post_id ) {
	if ( !wp_verify_nonce( $_POST['dimme-googlemaps'], plugin_basename(__FILE__) )) {
    return $post_id;
  }
  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
    return $post_id;
    
     // Check permissions
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return $post_id;
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;
	}
	
	$latitude = $_POST["latitude"];
	$longtitude = $_POST["longtitude"];
	add_post_meta( $post_id, 'latitude', $latitude, true ) or update_post_meta( $post_id, 'latitude', $latitude );
	add_post_meta( $post_id, 'longtitude', $longtitude, true ) or update_post_meta( $post_id, 'longtitude', $longtitude );
}
function my_dimme_googlemaps_init(){
	if(is_admin()) {
		//wp_enqueue_script('jquery');
		wp_enqueue_script('dimme_simple_googlemap', WP_PLUGIN_URL . '/dimme-googlemaps/googlemap.js');
		wp_enqueue_script('dimme_googlemaps-jsapi', 'http://www.google.com/jsapi');
		wp_enqueue_script('dimme_googlemaps', 'http://maps.google.com/maps/api/js?sensor=false');
		
		//wp_register_style('dimme_simple_googlemap_css', WP_PLUGIN_URL . '/dimme_googlemaps/simple_calendar.css');
		//wp_enqueue_style( 'dimme_simple_googlemap_css');
	} else {
		wp_enqueue_script('jquery');
		wp_enqueue_script('dimme_simple_googlemap', WP_PLUGIN_URL . '/dimme-googlemaps/googlemap-site.js');
		wp_enqueue_script('dimme_googlemaps-jsapi', 'http://www.google.com/jsapi');
		wp_enqueue_script('dimme_googlemaps', 'http://maps.google.com/maps/api/js?sensor=false');
	}
}

function dimme_googlemaps_content($content) {
	global $post;
	$postType = get_option('dimme_googlemaps_posttype');
	$postType = $postType ? $postType : "googlemap";
	if($postType == $post->post_type) {
		$content = "[dimme-googlemaps=" . $post->ID . "]" . $content;
	}
	
	if(preg_match_all("/\[dimme-googlemaps\=([0-9]+?)(.*?)\]/iU", $content, $matches, PREG_SET_ORDER)) {
		foreach($matches as $match) {
			$latitude = get_post_meta( $match[1], 'latitude', true);
			$longtitude = get_post_meta( $match[1], 'longtitude', true);
			if($latitude && $longtitude) {
				$str = '<div id="dimme-googlemaps-map" style="width:350px;height:250px;float:right;"></div>';
				$str .= '<script type="text/javascript">';
				$str .= 'var latitude = ' . $latitude . ';';
				$str .= 'var longtitude = ' . $longtitude . ';';
				$str .= '</script>';
				
				$content = str_replace($match[0], $str, $content);
			} else {
				$content = str_replace($match[0], "", $content);
			}
		}
	}
	return $content;
}
add_action('admin_menu', 'dimme_googlemaps_admin_actions');  
add_action('init', 'my_dimme_googlemaps_init');
add_action('add_meta_boxes', 'dimme_googlemaps_add_custom_box');
add_action('save_post', 'dimme_googlemaps_save_postdata');
add_filter('the_content', 'dimme_googlemaps_content');
